<template>
  <div class="mobile-container">
    <van-sticky class="containter-sticky">
      <navBar @clickLeft="onClickLeft" title="设备详情"></navBar>
    </van-sticky>
    <van-form @submit="onSubmit" label-width="auto">
      <van-field name="设备名称" label="设备名称" input-align="right">
        <template #input>
          {{ baseInfo.deviceName }}
        </template>
      </van-field>
      <van-field name="设备编号" label="设备编号" input-align="right">
        <template #input>
          {{ baseInfo.deviceCode }}
        </template>
      </van-field>
      <van-field name="所属区域" label="所属区域" input-align="right">
        <template #input>
          {{ baseInfo.areaName }}
        </template>
      </van-field>
      <van-field name="详情地址" label="详情地址" input-align="right">
        <template #input>
          {{ baseInfo.address }}
        </template>
      </van-field>
      <van-field name="设备状态" label="设备状态" input-align="right">
        <template #input>
          {{ baseInfo.deviceStatus === '1' ? '正常' : baseInfo.deviceStatus === '2' ? '故障' : baseInfo.deviceStatus === '3'
          ? '报警' : ''
          }}
        </template>
      </van-field>
      <van-field name="派遣人姓名" label="派遣人姓名" input-align="right">
        <template #input>
          {{ baseInfo.personName }}
        </template>
      </van-field>
      <van-field name="派遣人联系电话" label="派遣人联系电话" input-align="right">
        <template #input>
          {{ baseInfo.personPhone }}
        </template>
      </van-field>

      <template v-if="baseInfo.eventStatus !== 3">
        <van-field style="margin-top: 1rem;" v-model="formData.inspectionName" name="巡查姓名" label="巡查姓名"
                   input-align="right" :rules="[{ required: true, message: '请输入正确内容' }]" placeholder="请输入巡查姓名" />
        <van-field v-model="formData.inspectionPhone" name="巡查联系电话" label="巡查联系电话" input-align="right"
                   :rules="[{ required: true, message: '请输入正确内容' }]" placeholder="请输入巡查联系电话" />
        <van-field name="所属部门" label="所属部门" input-align="right">
          <template #input>
            <div @click="sectionShow = true">
              <span v-if="formData.inspectionDept">{{ formData.inspectionDept }}</span>
              <span v-else class="placeholder">请选择所属部门</span>
            </div>
            <van-action-sheet v-model="sectionShow" :actions="sectionList" cancel-text="取消" close-on-click-action
                              @cancel="onCancelSectionShow" @select="onSelectSectionShow" />
          </template>
        </van-field>
        <van-field name="巡检状态" label="巡检状态" input-align="right">
          <template #input>
            <div @click="show = true">
              <span v-if="formData.inspectionStatus">{{
                  formData.inspectionStatus === '1' ? '正常' : formData.inspectionStatus === '2' ? '故障'
                    : formData.inspectionStatus === '3' ? '报警' : ''
                }}</span>
              <span class="placeholder" v-else>请选择巡检状态</span>
            </div>
            <van-action-sheet v-model="show" :actions="actionsList" cancel-text="取消" close-on-click-action
                              @cancel="onCancel" @select="onSelect" />
          </template>
        </van-field>
        <van-field v-model="formData.description" v-if="formData.inspectionStatus && formData.inspectionStatus !== '1'"
                   rows="2" type="textarea" :rules="[{ required: true, message: '请输入正确内容' }]" placeholder="请输入故障描述" name="故障描述"
                   label="故障描述" input-align="right" />
        <van-field name="巡查时间" label="巡查时间" input-align="right">
          <template #input>
            <div @click="timeShow = true">
              <span v-if="formData.inspectionTime">{{ formData.inspectionTime }}</span>
              <span v-else class="placeholder">请选择巡查时间</span>
            </div>
            <van-action-sheet v-model="timeShow">
              <div class="content">
                <van-datetime-picker v-model="currentDate" type="date" title="选择巡检时间" @confirm="onSelectTime"
                                     @cancel="timeShow = false" />
              </div>
            </van-action-sheet>
          </template>
        </van-field>
        <van-field name="巡查图片" label="巡查图片" input-align="right">
          <template #input>
            <van-uploader v-model="fileList" :after-read="afterRead" :before-read="beforeAvatarUpload"
                          @delete="handleRemove" />
          </template>
        </van-field>
        <div class="footer">
          <van-button round block type="info" native-type="submit">确认</van-button>
        </div>
      </template>
      <template v-else>
        <van-field style="margin-top: 1rem;" name="巡查姓名" label="巡查姓名" input-align="right">
          <template #input>
            {{ formData.inspectionName }}
          </template>
        </van-field>
        <van-field name="巡查联系电话" label="巡查联系电话" input-align="right">
          <template #input>
            {{ formData.inspectionPhone }}
          </template>
        </van-field>
        <van-field name="所属部门" label="所属部门" input-align="right">
          <template #input>
            {{ formData.inspectionDept }}
          </template>
        </van-field>
        <van-field name="巡检状态" label="巡检状态" input-align="right">
          <template #input>
            {{
              formData.inspectionStatus === '1' ? '正常' : formData.inspectionStatus === '2' ? '故障'
                : formData.inspectionStatus === '3' ? '报警' : ''
            }}
          </template>
        </van-field>
        <van-field v-if="formData.inspectionStatus && formData.inspectionStatus !== '1'" name="故障描述" label="故障描述"
                   input-align="right">
          <template #input>
            {{ formData.description }}
          </template>
        </van-field>
        <van-field name="巡查时间" label="巡查时间" input-align="right">
          <template #input>
            {{ formData.inspectionTime }}
          </template>
        </van-field>
        <van-field name="巡查图片" label="巡查图片" input-align="right">
          <template #input>
            <div class="detailFile" v-if="fileList.length">
              <van-uploader v-model="fileList" :after-read="afterRead" :before-read="beforeAvatarUpload"
                            @delete="handleRemove" />
            </div>
            <div v-else>暂无图片</div>
          </template>
        </van-field>

        <van-steps direction="vertical" :active="-1">
          <van-step v-for="(item, index) in eventDisposalInfoList" :key="index">
            <div class="node">处置节点名称：{{ item.handleNodeName || '-' }}</div>
            <div class="name">处置人员：{{ item.handlePerson || '-' }}</div>
            <div class="name">处置部门：{{ item.handleDeptName || '-' }}</div>
            <div>处理描述：{{ item.handleDesc || '-' }}</div>
            <div>{{ item.handleTime || '-' }}</div>
          </van-step>
        </van-steps>
      </template>

    </van-form>
  </div>
</template>
<script>
import api from '@/api/device/Inspection.js'
import navBar from '../../components/navBar.vue'
import moment from 'moment'
import { mapState } from 'vuex'
import { ImagePreview } from 'vant'

export default {
  name: 'InspectionDetail',
  components: {
    [ImagePreview.Component.name]: ImagePreview.Component,
    navBar
  },
  data() {
    return {
      baseInfo: {},
      formData: {
        inspectionName: '',
        inspectionPhone: '',
        inspectionDept: '',
        inspectionStatus: '',
        description: '',
        inspectionTime: '',
        inspectionImgUrl: []
      },
      show: false,
      actionsList: [{ name: '正常', value: '1' }, { name: '故障', value: '2' }, { name: '报警', value: '3' }],
      sectionShow: false,
      sectionList: [],//部门
      timeShow: false,
      currentDate: new Date(),
      uploadUrl: window.context.portal + '/file/v1/uploadFileForConfig', // 服务器上传地址
      previewUrl:
        window.context.portal + '/file/onlinePreviewController/v1/getFileById_',
      fileList: [],
      eventDisposalInfoList: []
    }
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
    this.getBaseInfo()
    this.getSection()
  },
  mounted() {
    this.getData()
  },
  methods: {
    async getBaseInfo() {
      this.baseInfo = this.$route.params.equipment
      const { productId, taskId, deviceId } = this.baseInfo
      this.formData = { ...this.formData, productId, taskId, deviceId }
      let data = this.$store.state.user.currentUserDetail || null
      if (data) {
        let { mobile: inspectionPhone, fullname: inspectionName, id: inspectionUser } = data.user
        let { orgName: inspectionDept } = data?.org[0]
        let formData = {
          ...this.formData,
          inspectionPhone, inspectionName, inspectionUser, inspectionDept
        }
        this.$set(this, 'formData', formData)
      } else {
        this.$store.dispatch('user/loadCurrentUserDetail').then(async res => {
          let { mobile: inspectionPhone, fullname: inspectionName, id: inspectionUser } = res?.user
          let { orgName: inspectionDept } = res?.org[0]
          let formData = {
            ...this.formData,
            inspectionPhone, inspectionName, inspectionUser, inspectionDept
          }
          this.$set(this, 'formData', formData)
        })
      }
    },
    //获取详情
    getData() {
      if (this.baseInfo?.resultId) {
        const toast = this.$toast.loading({
          duration: 0, // 持续展示 toast
          forbidClick: true,
          message: '加载中...',
        });
        api.getResultDetails(this.baseInfo.resultId, res => {
          if (res) {
            let imgArr = res.inspectionImgUrl != '' ? res.inspectionImgUrl?.split(',') : []
            this.formData = {
              ...this.formData,
              ...res,
              inspectionImgUrl: imgArr
            }
            this.formData.inspectionTime = moment(this.currentDate).format('YYYY-MM-DD')
            imgArr.forEach(id => {
              this.fileList.push({ url: this.previewUrl + id, isImage: true })
            })
          }
          toast.clear()
        })


      }
      if (this.baseInfo?.warningId && this.baseInfo.eventStatus > 2) {
        api.getEventDetails(this.baseInfo.warningId, res => {
          if (res.successFlag) {
            this.eventDisposalInfoList = res.content?.eventDisposalInfoList.reverse()
          }
        })
      }
    },
    //获取组织部门
    getSection() {
      api.byParentAndDemToTree({}, res => {
        if (res) {
          this.sectionList = res
        }
      })
    },
    onSelect(item) {
      this.formData.inspectionStatus = item.value
      this.$set(this.formData)
      this.show = false
    },
    onCancel() {
      this.show = false
    },
    onClickLeft() {
      this.$router.go(-1)
    },
    // 部门取消
    onCancelSectionShow() {
      this.sectionShow = false
    },
    //部门确认
    onSelectSectionShow(item) {
      this.formData.inspectionDept = item.name
      this.formData.affiliationUnitId = item.id
      this.$set(this.formData)
      this.sectionShow = false
    },
    onSelectTime() {
      this.formData.inspectionTime = moment(this.currentDate).format('YYYY-MM-DD')
      this.timeShow = false
    },
    onSubmit() {
      const { productName, deviceName, deviceCode, areaName, address } = this.baseInfo
      if (this.formData.inspectionStatus == '' || this.formData.inspectionDept == '' || this.formData.inspectionTime == '') {
        this.$toast({
          message: '请填写完整信息!',
          position: 'top'
        })
      } else {
        let data = JSON.parse(JSON.stringify(this.formData))
        data.inspectionImgUrl = data.inspectionImgUrl?.join(',') || ''
        data.inspectionTime = moment(data.inspectionTime).format('YYYY-MM-DD hh:mm:ss')
        data = {
          ...data,
          productName, deviceName, deviceCode, areaName, address
        }
        let msg = data.id ? '修改保存' : '录入保存'
        const toast = this.$toast.loading({
          duration: 0, // 持续展示 toast
          forbidClick: true,
          message: `${msg}中...`,
        });

        api.resultEnter(data, res => {
          if (res.state) {
            this.$toast.success(`${msg}成功`)
            this.onClickLeft()
          }
          toast.clear()
        })
      }
    },
    // 文件上传前
    beforeAvatarUpload(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt10M = file.size / 1024 / 1024 < 100
      if (!isJPG) {
        this.$toast({
          message: '上传图片只能是 JPG 格式!',
          position: 'top'
        })
      }
      if (!isLt10M) {
        this.$toast({
          message: '上传图片大小不能超过 100MB!',
          position: 'top'
        })
      }
      return isJPG && isLt10M
    },
    // 文件上传
    afterRead(file) {
      const toast = this.$toast.loading({
        duration: 0, // 持续展示 toast
        forbidClick: true,
        message: '图片上传中',
      });
      let formData = new FormData()
      formData.append('files', file.file)
      let data = { bizCode: 'inspectionImage', bizId: '' }
      api.uploadImg(data, formData, res => {
        if (res.success) {
          let { fileId } = res
          toast.clear()
          this.$toast('图片上传成功')
          this.formData.inspectionImgUrl.push(fileId)
        }
      })
    },
    // 文件删除 
    handleRemove(file, { index }) {
      let id = this.formData.inspectionImgUrl[index]
      api.deleteImg(id, res => {
        if (res.state) {
          this.$toast('图片删除成功')
          this.formData.inspectionImgUrl.splice(index, 1)
          console.log(this.formData.inspectionImgUrl);
        }
      })

      // let id = file.url.split('_').pop()
      // this.formData.inspectionImgUrl.forEach((e, index) => {
      //   if ((this.previewUrl + e) == file.url) {
      //     this.formData.inspectionImgUrl.splice(index, 1)
      //   }
      //   // if (e == id) {
      //   //     this.formData.inspectionImgUrl.splice(index, 1)
      //   // }
      // })
    },
    // // 图片转换
    // convertImg(arr) {
    //   console.log(arr)
    //   let newArr = []
    //   if (Array.isArray(arr)) {
    //     newArr = arr.map(it => {
    //       console.log(this.previewUrl + it)
    //       return { url: this.previewUrl + it, id: it.id }
    //     })
    //     return newArr
    //   }
    //   console.log(newArr)
    // }
  }
}
</script>
<style lang="scss" scoped>
.detailFile {
  ::v-deep .van-uploader__upload {
    display: none;
  }

  ::v-deep .van-uploader__preview-delete {
    display: none;
  }
}

.mobile-container {
  width: 100%;
  background-color: #f9f9f9 !important;
  box-sizing: border-box;

  // background-color: $--mobile-bg;
  .containter-sticky {
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 200;
  }
}

.placeholder {
  color: #c7c5c5;
}

.footer {
  position: fixed;
  bottom: 0;
  width: 100%;
  background: #fff;
  padding: 1rem;
  box-sizing: border-box;

}

// .file{
//     width: 3rem;
//     height: 3rem;
// }
::v-deep .el-upload-list--picture-card .el-upload-list__item {
  width: 7rem;
  height: 7rem;
}

::v-deep .el-upload--picture-card {
  width: 7rem;
  height: 7rem;
}

::v-deep .el-upload--picture-card i {
  font-size: 1.8rem;
  line-height: 7rem;
}

::v-deep .van-popup--bottom.van-popup--round {
  max-height: 40%;
}
</style>
